@@ -32,15 +32,21 @@ unless (GetOptions('diffs' => \$diffs,
 die "$0: This does not look like a Perl directory\n"
     unless -f "perl.h" && -d "Porting";
 die "$0: 'This is a Perl directory but does not look like Git working directory\n"
-    unless -d ".git";
+    unless (-d ".git" || (exists $ENV{GIT_DIR} && -d $ENV{GIT_DIR}));
 
 my $null = devnull();
 
 unless (defined $tag_to_compare) {
+    my $check = 'HEAD';
+    while(1) {
+        $check = `git describe --abbrev=0 $check 2>$null`;
+        chomp $check;
+        last unless $check =~ /-RC/;
+        $check .= '~1';
+    }
+    $tag_to_compare = $check;
     # Thanks to David Golden for this suggestion.
 
-    $tag_to_compare = `git describe --abbrev=0 2>$null`;
-    chomp $tag_to_compare;
 }
 
 unless (length $tag_to_compare) {
@@ -77,6 +83,11 @@ my %skip;
 @skip{
     'cpan/ExtUtils-MakeMaker/t/lib/MakeMaker/Test/Setup/BFD.pm', # just a test module
     'cpan/ExtUtils-MakeMaker/t/lib/MakeMaker/Test/Setup/XS.pm',  # just a test module
+    'cpan/Module-Build/t/lib/DistGen.pm', # just a test module
+    'cpan/Module-Build/t/lib/MBTest.pm',  # just a test module
+    'cpan/Module-Metadata/t/lib/DistGen.pm',    # just a test module
+    'cpan/Module-Metadata/t/lib/MBTest.pm',     # just a test module
+    'cpan/Module-Metadata/t/lib/Tie/CPHash.pm', # just a test module
     'dist/Attribute-Handlers/demo/MyClass.pm', # it's just demonstration code
     'dist/Exporter/lib/Exporter/Heavy.pm',
     'lib/Carp/Heavy.pm',
@@ -114,6 +125,7 @@ sub pm_file_from_xs {
 			 # look for a .pm in lib/ based on that:
 			 my ($path) = shift =~ m!^(.*)/!;
 			 my ($last) = $path =~ m!([^/]+)\z!;
+			 $last = 'List-Util' if $last eq 'Scalar-List-Utils';
 			 $last =~ tr !-!/!;
 			 return "$path/lib/$last";
 		     }) {
@@ -183,11 +195,11 @@ foreach my $pm_file (sort keys %module_diffs) {
 		and grep $pm_version eq $_, @{$skip_versions{$pm_file}}) {
 		print "ok $count - SKIP $pm_file version $pm_version\n";
 	    } else {
-		print "not ok $count - $pm_file\n";
+		print "not ok $count - $pm_file version $pm_version\n";
 	    }
 	} else {
 	    push @diff, @{$module_diffs{$pm_file}};
-	    print "$pm_file\n";
+	    print "$pm_file version $pm_version\n";
 	}
     }
 }
